@@ -22,15 +22,14 @@
 
 #include "util.h"
 
-#define XC_GGA_C_OP_B88      87 /* one-parameter progressive functional (B88 version) */
-#define XC_GGA_C_OP_PBE      86 /* one-parameter progressive functional (PBE version)  */
-#define XC_GGA_C_OP_G96      85 /* one-parameter progressive functional (G96 version)  */
-#define XC_GGA_C_OP_XALPHA   84 /* one-parameter progressive functional (G96 version)  */
+#define XC_GGA_C_OP_B88      87 /* one-parameter progressive functional (B88 version)     */
+#define XC_GGA_C_OP_PBE      86 /* one-parameter progressive functional (PBE version)     */
+#define XC_GGA_C_OP_G96      85 /* one-parameter progressive functional (G96 version)     */
+#define XC_GGA_C_OP_XALPHA   84 /* one-parameter progressive functional (XALPHA version)  */
 
 typedef struct{
   FLOAT qOPab;
-  void (*enhancement_factor)
-    (const XC(func_type) *p, int order, FLOAT x, FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2);
+  xc_gga_enhancement_t enhancement_factor;
 } gga_c_op_params;
 
 
@@ -93,8 +92,8 @@ func(const XC(func_type) *p, XC(gga_work_c_t) *r)
   }else{
     /* call enhancement factor */
     if(p->info->number != XC_GGA_C_OP_XALPHA){
-      params->enhancement_factor(p->func_aux[0], r->order, r->xs[0], &eu_f, &eu_dfdx, &eu_d2fdx2);
-      params->enhancement_factor(p->func_aux[0], r->order, r->xs[1], &ed_f, &ed_dfdx, &ed_d2fdx2);
+      params->enhancement_factor(p->func_aux[0], r->order, r->xs[0], &eu_f, &eu_dfdx, &eu_d2fdx2, NULL);
+      params->enhancement_factor(p->func_aux[0], r->order, r->xs[1], &ed_f, &ed_dfdx, &ed_d2fdx2, NULL);
     }else{
       eu_f = ed_f = 1.0;
       eu_dfdx = ed_dfdx = 0.0;
