@@ -23,15 +23,15 @@
 #define XC_GGA_X_DK87_R1      111 /* dePristo & Kress 87 (version R1)               */
 #define XC_GGA_X_DK87_R2      112 /* dePristo & Kress 87 (version R2)               */
 
-static inline void 
-func(const XC(func_type) *p, int order, FLOAT x, 
-     FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2)
+void XC(gga_x_dk87_enhance)
+  (const XC(func_type) *p, int order, FLOAT x, 
+   FLOAT *f, FLOAT *dfdx, FLOAT *d2fdx2, FLOAT *d3fdx3)
 {
   static const FLOAT a1[2] = {0.861504, 0.861213}, 
     b1[2] = {0.044286, 0.042076}, alpha[2] = {1.0, 0.98};
   static const FLOAT betag = 0.00132326681668994855/X_FACTOR_C; /* 7/(432*pi*(6*pi^2)^(1/3)) */
   
-  FLOAT f0, f1, f2, df1, df2, d2f1, d2f2;
+  FLOAT f0, f1, f2, df1, df2, d2f1, d2f2, d3f1;
   int func;
 
   switch(p->info->number){
@@ -47,19 +47,26 @@ func(const XC(func_type) *p, int order, FLOAT x,
 
   if(order < 1) return;
 
-  df1 = betag*x*(2.0 + f0*(2.0 + alpha[func]));
+  df1 = betag*x*(2.0 + (2.0 + alpha[func])*f0);
   df2 = 2.0*b1[func]*x;
 
-  *dfdx  = (df1*f2 - f1*df2)/(f2*f2);
+  *dfdx  = DFRACTION(f1, df1, f2, df2);
   
   if(order < 2) return;
 
-  d2f1 = betag*(2.0 + f0*(2.0 + alpha[func])*(1.0 + alpha[func]));
+  d2f1 = betag*(2.0 + (1.0 + alpha[func])*(2.0 + alpha[func])*f0);
   d2f2 = 2.0*b1[func];
 
-  *d2fdx2 = (2.0*f1*df2*df2 + d2f1*f2*f2 - f2*(2.0*df1*df2 + f1*d2f2))/(f2*f2*f2);
+  *d2fdx2 = D2FRACTION(f1, df1, d2f1, f2, df2, d2f2);
+
+  if(order < 3) return;
+
+  d3f1 = betag*alpha[func]*(1.0 + alpha[func])*(2.0 + alpha[func])*f0/x;
+  
+  *d3fdx3 = D3FRACTION(f1, df1, d2f1, d3f1, f2, df2, d2f2, 0.0);
 }
 
+#define func XC(gga_x_dk87_enhance)
 #include "work_gga_x.c"
 
 const XC(func_info_type) XC(func_info_gga_x_dk87_r1) = {
@@ -68,7 +75,7 @@ const XC(func_info_type) XC(func_info_gga_x_dk87_r1) = {
   "dePristo & Kress 87 version R1",
   XC_FAMILY_GGA,
   "AE DePristo and JD Kress, J. Chem. Phys. 86, 1425 (1987)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-24, 1e-24, 0.0, 1e-32,
   NULL, NULL, NULL,
   work_gga_x,
@@ -81,7 +88,7 @@ const XC(func_info_type) XC(func_info_gga_x_dk87_r2) = {
   "dePristo & Kress 87 version R2",
   XC_FAMILY_GGA,
   "AE DePristo and JD Kress, J. Chem. Phys. 86, 1425 (1987)",
-  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC,
+  XC_FLAGS_3D | XC_FLAGS_HAVE_EXC | XC_FLAGS_HAVE_VXC | XC_FLAGS_HAVE_FXC | XC_FLAGS_HAVE_KXC,
   1e-32, 1e-32, 0.0, 1e-32,
   NULL, NULL, NULL,
   work_gga_x,
